## 2.1.0.20260117 (2026-01-17)

[stubsabot] Bump Send2Trash to 2.1.* ([#15197](https://github.com/python/typeshed/pull/15197))

## 2.0.0.20260116 (2026-01-16)

[Send2Trash] Update to 2.0.* ([#15202](https://github.com/python/typeshed/pull/15202))

## 1.8.2.7 (2023-07-25)

Complete send2trash stubs (#10504)

## 1.8.2.6 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 1.8.2.5 (2023-05-10)

Add `partial_stub` metadata field (#10157)

## 1.8.2.4 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.8.2.3 (2022-11-16)

Always use `bool` and `Literal` for Python compat code (#9213)

## 1.8.2.2 (2022-11-03)

Remove `Send2Trash` from `pyright`'s exclude (#8944)

## 1.8.2.1 (2022-10-15)

Use `Incomplete` instead of `Any` in `__getattr__` (#8903)

## 1.8.1 (2021-10-12)

Add star to all non-0.1 versions (#6146)

## 1.8.0 (2021-09-03)

Create send2trash stubs (#6000)

